summaryrefslogtreecommitdiff
path: root/gnuradio-runtime/python/gnuradio/gr/top_block.py
diff options
context:
space:
mode:
authorluz.paz <luzpaz@users.noreply.github.com>2019-07-09 16:27:22 -0400
committerMarcus Müller <marcus@hostalia.de>2019-07-17 22:54:23 +0200
commit925e1103e5791dc8be684a5269efc36c1bf4f557 (patch)
treeb56cbff2a2bb8e7f16805197d2c729397c5ec4f6 /gnuradio-runtime/python/gnuradio/gr/top_block.py
parent15452407e043b3d1fe3f152c2590bc95b40b4342 (diff)
Fix for misc. documentation + trivial typos
Found via `codespell -q 3 -L ans,sinc,hist,ist,ith,uint,fo -S ./volk` Fix typos in gnuradio-runtime/ Fix typos in gr-digital/ Fix typos in gr-qtgui/ Fix typos in gr-channels/ Fix typos in grc/ Fix typos gr-filter/ Fix typos in gr-uhd/ Fix typos in gr-blocks/ Fix typos in gr-fec/
Diffstat (limited to 'gnuradio-runtime/python/gnuradio/gr/top_block.py')
-rw-r--r--gnuradio-runtime/python/gnuradio/gr/top_block.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/gnuradio-runtime/python/gnuradio/gr/top_block.py b/gnuradio-runtime/python/gnuradio/gr/top_block.py
index afa9c3b986..87c3a81852 100644
--- a/gnuradio-runtime/python/gnuradio/gr/top_block.py
+++ b/gnuradio-runtime/python/gnuradio/gr/top_block.py
@@ -44,7 +44,7 @@ class _top_block_waiter(threading.Thread):
thread), we create a separate thread that does the blocking wait,
and then use the thread that called wait to do a slow poll of an
event queue. That thread, which is executing "wait" below is
interruptable, and if it sees a KeyboardInterrupt, executes a stop
on the top_block, then goes back to waiting for it to complete.
This ensures that the unlocked wait that was in progress (in the
_top_block_waiter thread) can complete, release its mutex and back
@@ -52,7 +52,7 @@ class _top_block_waiter(threading.Thread):
things occur like leaving the USRP transmitter sending a carrier.
See also top_block.wait (below), which uses this class to implement
- the interruptable wait.
+ the interruptible wait.
"""
def __init__(self, tb):
threading.Thread.__init__(self)
@@ -44,7 +44,7 @@ class _top_block_waiter(threading.Thread):
and then use the thread that called wait to do a slow poll of an
event queue. That thread, which is executing "wait" below is
- interruptable, and if it sees a KeyboardInterrupt, executes a stop
+ interruptible, and if it sees a KeyboardInterrupt, executes a stop
on the top_block, then goes back to waiting for it to complete.
This ensures that the unlocked wait that was in progress (in the